import os

import axipy
from PySide2.QtGui import QIcon
from axipy import Plugin, Position, view_manager, VectorLayer, show_message, DlgIcon, DlgButtons, show_dialog

from ru_axioma_gis_label_to_text.ui.dlgRun import RunLabelToText
from ru_axioma_gis_label_to_text.ui.tools.helper_tab import getPathOutTable, createTableForLabel
from ru_axioma_gis_label_to_text.ui.tools.observer_layer_select import factoryObserver, getSelectLayerInLayerControl


class MarkerInReport(Plugin):
    def __init__(self):
        super().__init__()
        self.__header_message="Преобразование подписей в текст"
        self.__name = "Подписи в текст"
        self.__form_tool = None
        self.__docWidget = None
        self._title = self.tr(self.__name)
        self.__name_observer="ActiveMapView"
        self.__observer=factoryObserver(self.__name_observer)
        local_file_icon_1 = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'ui/icons', 'labeler_32x32.png')
        self.__icon_tools = QIcon(local_file_icon_1)
        self.__action = self.create_action(self.__name,
                                                      icon=local_file_icon_1, on_click=self.__run,enable_on=self.__name_observer)
        position = Position('Карта', 'Инструменты')
        position.add(self.__action)



    def __run(self):
        layers_select=getSelectLayerInLayerControl(view_manager.active)
        if layers_select is None:
            show_message('В активной карте не выбран слой с подписями', self.__header_message, icon=DlgIcon.INFORMATION)
            return
        if len(layers_select)>1:
            show_message('В активной карте выбрано белее одного слоя', self.__header_message, icon=DlgIcon.INFORMATION)
            return
        selected_layer=layers_select[0]
        if not isinstance(selected_layer,VectorLayer):
            show_message('В активной карте выбран не векторный слой', self.__header_message, icon=DlgIcon.INFORMATION)
            return
        if not selected_layer.label.visible:
            res = show_dialog('Подписать слой ?', self.__header_message,
                              icon=DlgIcon.QUESTION,
                              default_button=DlgButtons.NO,
                              buttons=DlgButtons.YES_NO)
            if res==DlgButtons.NO:
                return
            selected_layer.label.visible=True
        path_out_label=getPathOutTable(selected_layer.data_object,"_подписи")
        cls_run=RunLabelToText(selected_layer,axipy.mainwindow.widget)
        tab_out_label=createTableForLabel(path_out_label,selected_layer.data_object.coordsystem)
        cls_run.exec_(view_manager.active,selected_layer,tab_out_label)
    def unload(self) -> None:
        self.__action.remove()